API docs for “spamfighter.api.domain”

# Package s.a.domain

Part of spamfighter.api View Source

Набор команд СпамоБорца `sf.domain.*`.

Module | children | Команда `sf.domain.children` - получение списка имён поддоменов.
Module | get | Команда `sf.domain.get` - получение информации об одном свойстве домена.
Module | list | Команда `sf.domain.list` - получение списка имён свойств домена.
Package | test | Тесты на `spamfighter.api.domain`.